@@ -14,6 +14,6 @@ from .server import blueprint as server_blueprint
 from .settings import blueprint as settings_blueprint
 
 __all__ = (
-    'server_blueprint',
-    'settings_blueprint',
+    "server_blueprint",
+    "settings_blueprint",
 )
