@@ -15,19 +15,19 @@ from invenio_db import db
 
 def test_alembic(app):
     """Test alembic recipes."""
-    ext = app.extensions['invenio-db']
+    ext = app.extensions["invenio-db"]
 
     with app.app_context():
-        if db.engine.name == 'sqlite':
-            raise pytest.skip('Upgrades are not supported on SQLite.')
+        if db.engine.name == "sqlite":
+            raise pytest.skip("Upgrades are not supported on SQLite.")
 
         assert not ext.alembic.compare_metadata()
         db.drop_all()
         ext.alembic.upgrade()
 
         assert not ext.alembic.compare_metadata()
-        ext.alembic.downgrade(target='96e796392533')
+        ext.alembic.downgrade(target="96e796392533")
         ext.alembic.upgrade()
 
         assert not ext.alembic.compare_metadata()
-        ext.alembic.downgrade(target='96e796392533')
+        ext.alembic.downgrade(target="96e796392533")
